@@ -1,6 +1,15 @@
 package Kephra::App::Panel;
 our $VERSION = '0.00';
 
+use strict;
+use warnings;
+
+my ($left,$right,$bottom);
+
+sub new {}
+
+1;
+
 =head1 NAME
 
 Kephra::Panel - Manager to all side panels 
@@ -8,9 +17,4 @@ Kephra::Panel - Manager to all side panels
 =head1 DESCRIPTION
 
 
-=cut
-
-use strict;
-use warnings;
-
-1;
\ No newline at end of file
+=cut
\ No newline at end of file
